Learn R Programming

mau (version 0.4.0)

bar_plot: Bar plot of utilities

Description

Create ggplot2 bar plots of the utilities at any level of the decision model

Usage

bar_plot(model, deep, colors, title, xlab, ylab)

Value

ggplot2 object.

Arguments

model

data.table obtained with compute_model

deep

the deep to navigate the model object a select the utilities

colors

a list of colors for the bars

title

title for the bar plot

xlab

label for horizontal axis

ylab

label for vertical axis

Author

Pedro Guarderas pedro.felipe.guarderas@gmail.com

Examples

Run this code
library( mau )
vignette( topic = 'Running_MAUT', package = 'mau' ) 

Run the code above in your browser using DataLab