Learn R Programming

mau (version 0.4.0)

compute_model: Evaluation of decision tree nodes

Description

Evaluation of decision tree nodes. All the MAUT model is computed at every level the utilities are computed considering the given weights.

Usage

compute_model(tree, utilities, weights)

Value

data.table structure containing the utilities of the model for every level the decision tree.

Arguments

tree

initial tree structure with utilities in its leafs.

utilities

data.table with ordered columns containing the values of utilities.

weights

weights for the decision model.

Author

Pedro Guarderas, Andrés Lopez pedro.felipe.guarderas@gmail.com

Details

The whole decision model can be computed a any level and represented in a table format.

See Also

stand_string, read_utilities, eval_utilities, read_tree, make_decision_tree, sim_const_weights.

Examples

Run this code
vignette( topic = 'Running_MAUT', package = 'mau' )

Run the code above in your browser using DataLab