deep_compute: Compute the deep position of every node

View source: R/make_tree.R

deep_computeR Documentation

Compute the deep position of every node

Description

For the computation of the complete decision model is necessary to establish the deep position of every node.

Usage

deep_compute(tree)

Arguments

tree

igraph object representing the tree

Value

igraph object updated

Author(s)

Pedro Guarderas, Andrés Lopez

See Also

read_tree


mau documentation built on Feb. 13, 2026, 5:10 p.m.