powered by
After the addition of weights for internal nodes the final weights have to be computed dividing by the total weight of each parent.
divide_weights(tree)
igraph object updated
igraph object representing the tree
Pedro Guarderas, Andrés Lopez
read_tree