Spider plot for the decision model considering the weights simulated with a Dirichlet distributions, every simulation is represented with lines, a box plot is included to account the behavior of every global utility.
plot_sim_weight(
S,
title = "Simulations",
xlab = "ID",
ylab = "Utility",
lines.cols = "blue",
box.col = "gold",
box.outlier.col = "darkred",
utility.col = "darkgreen",
utility.point.col = "darkgreen",
text.col = "black"
)ggplot object with the plot of simulations.
first element of the simulation list produced by the function
sim_weights, sim_const_weights.
text for the title plot.
text for x-axis label.
text for y-axis label.
the spectrum of colors for the simulation is selected randomly from a base color.
color for the boxes.
color for the outlier points representing the extreme observations in the boxplot.
the main utility value is also plotted with this specific color.
the line of main utilities is plotted with points represented with this color.
color for the text values plotted for each utility.
Pedro Guarderas
sim_const_weights sim_weights