Learn R Programming

mau (version 0.4.0)

read_utilities: Read utilities

Description

Builds utility functions from definition standard.

Usage

read_utilities(file, lines, skip = 2, encoding = "utf-8", envir = .GlobalEnv)

Value

Returns data table with definition of utility functions by range.

Arguments

file

standardize file with definitions.

lines

number lines to read in file.

skip

to read the file it had to skip a given number of lines.

encoding

file encoding.

envir

environment where utility functions will be created.

Author

Pedro Guarderas, Andrés Lopez

Details

The basic MAUT models are built with functions of constant absolute risk aversion, this functions could be defined with simple parameters, only is necessary a function name and the domain of definition of every function and more important is necessary no more than three coefficients for the function definition.

See Also

stand_string

Examples

Run this code
library( data.table )
file <- system.file("extdata", "utilities.txt", package = "mau" )
lines <- 17
skip <- 2
encoding <- 'utf-8'
functions <- read_utilities( file, lines, skip, encoding )

Run the code above in your browser using DataLab