Learn R Programming

mau (version 0.4.0)

sim_weights: Simulation of weights

Description

Simulation of weights employing the Dirichlet distribution. The concentration parameters for the Dirichlet distribution are tentative weights.

Usage

sim_weights(n, utilities, alpha)

Value

List with data.frames {simulation, weights} with total utilities and simulated weights

Arguments

n

number of simulations

utilities

utility dataframe, first column is the identifier

alpha

concentration parameter for the Dirichlet distribution

Author

Pedro Guarderas pedro.felipe.guarderas@gmail.com

Details

Taking advantage of the Dirichlet distribution properties, the weights could be simulated with a concentration around given weights.

See Also

eval_utilities

Examples

Run this code
library( data.table )
N <- 10
utilities <- data.table( id = 1:N, 
                       u1 = runif( N, 0, 1 ), 
                       u2 = runif( N, 0, 1 ), 
                       u3 = runif( N, 0, 1 ),
                       u4 = runif( N, 0, 1 ) )
n <- 100
alpha <- c( 0.2, 0.5, 0.1, 0.2 )
S <- sim_weights( n, utilities, alpha )

Run the code above in your browser using DataLab