sum_weights: Sum weights for internal nodes

View source: R/make_tree.R

sum_weightsR Documentation

Sum weights for internal nodes

Description

The weights of the internal nodes has to be computed first is necessary to add each weights of the leaves.

Usage

sum_weights(tree)

Arguments

tree

igraph object representing the tree

Value

igraph object updated

Author(s)

Pedro Guarderas, Andrés Lopez

See Also

read_tree


mau documentation built on Feb. 13, 2026, 5:10 p.m.