powered by
Create ggplot2 bar plots of the utilities at any level of the decision model
bar_plot(model, deep, colors, title, xlab, ylab)
ggplot2 object.
data.table obtained with compute_model
compute_model
the deep to navigate the model object a select the utilities
a list of colors for the bars
title for the bar plot
label for horizontal axis
label for vertical axis
Pedro Guarderas pedro.felipe.guarderas@gmail.com
library( mau ) vignette( topic = 'Running_MAUT', package = 'mau' )
Run the code above in your browser using DataLab