powered by
Evaluation of decision tree nodes. All the MAUT model is computed at every level the utilities are computed considering the given weights.
compute_model(tree, utilities, weights)
data.table structure containing the utilities of the model for every level the decision tree.
initial tree structure with utilities in its leafs.
data.table with ordered columns containing the values of utilities.
weights for the decision model.
Pedro Guarderas, Andrés Lopez pedro.felipe.guarderas@gmail.com
The whole decision model can be computed a any level and represented in a table format.
stand_string, read_utilities, eval_utilities, read_tree, make_decision_tree, sim_const_weights.
stand_string
read_utilities
eval_utilities
read_tree
make_decision_tree
sim_const_weights
vignette( topic = 'Running_MAUT', package = 'mau' )
Run the code above in your browser using DataLab