Learn R Programming

mau (version 0.4.0)

deep_compute: Compute the deep position of every node

Description

For the computation of the complete decision model is necessary to establish the deep position of every node.

Usage

deep_compute(tree)

Value

igraph object updated

Arguments

tree

igraph object representing the tree

Author

Pedro Guarderas, Andrés Lopez

See Also

read_tree