powered by
For the computation of the complete decision model is necessary to establish the deep position of every node.
deep_compute(tree)
igraph object updated
igraph object representing the tree
Pedro Guarderas, Andrés Lopez
read_tree