Returns data table with definition of utility functions by range.
Arguments
file
standardize file with definitions.
lines
number lines to read in file.
skip
to read the file it had to skip a given number of lines.
encoding
file encoding.
envir
environment where utility functions will be created.
Author
Pedro Guarderas, Andrés Lopez
Details
The basic MAUT models are built with functions of constant absolute risk aversion,
this functions could be defined with simple parameters, only is necessary a function name and
the domain of definition of every function and more important is necessary no more than three
coefficients for the function definition.