Learn R Programming

mau (version 0.4.0)

sum_weights: Sum weights for internal nodes

Description

The weights of the internal nodes has to be computed first is necessary to add each weights of the leaves.

Usage

sum_weights(tree)

Value

igraph object updated

Arguments

tree

igraph object representing the tree

Author

Pedro Guarderas, Andrés Lopez

See Also

read_tree