powered by
The weights of the internal nodes has to be computed first is necessary to add each weights of the leaves.
sum_weights(tree)
igraph object updated
igraph object representing the tree
Pedro Guarderas, Andrés Lopez
read_tree